==> azorius-0.3.2.tgz: azorius-0.3.2/upgradedb.go <==
//
// Copyright (c) 2023 Ted Unangst <tedu@tedunangst.com>
//
// Permission to use, copy, modify, and distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

package main

import (
	"database/sql"
	"fmt"
	"os"
	"time"
)

var myVersion = 11 // index subs

func upgradedb() {
	db := opendatabase()
	dbversion := 0
	getconfig("dbversion", &dbversion)
	getconfig("servername", &serverName)
	serverPrefix = fmt.Sprintf("https://%s/", serverName)

	try := func(s string, args ...interface{}) {
		_, err := db.Exec(s, args...)
		if err != nil {
			elog.Fatalf("can't run %s: %s", s, err)
		}
	}
	setversion := func(version int) {
		try("update config set value = ? where key = 'dbversion'", version)
	}

	switch dbversion {
	case 0:
		os.Mkdir(dataDir+"/tempstore", 0755)
		try("create table reports (reportid integer primary key, who text, what text, were text, dt text, meta text)")
		setversion(1)
		fallthrough
	case 1:
		try("create table tombstones (tombstoneid integer primary key, what text)")
		setversion(2)
		fallthrough
	case 2:
		try("create table seckeys (seckeyid integer primary key, owner text, seckey text)")
		try("create index idxseckeys_owner on seckeys(owner)")
		tx, err := db.Begin()
		if err != nil {
			elog.Fatal(err)
		}
		copykeys := func(rows *sql.Rows) {
			type info struct {
				apid   string
				Pubkey string
				Seckey string
			}
			var keys []info
			for rows.Next() {
				var reset bool
				var apid, j string
				err := rows.Scan(&reset, &apid, &j)
				if err == nil && isMine(apid) {
					var key info
					if reset {
						key.Pubkey, key.Seckey, err = generateKeys()
					} else {
						err = unjsonify(j, &key)
					}
					key.apid = apid
					if err == nil {
						keys = append(keys, key)
					}
				}
				if err != nil {
					elog.Fatal(err)
				}
			}
			rows.Close()
			dt := time.Now().UTC().Format(dbtimeformat)
			for _, key := range keys {
				_, err := tx.Exec("insert into pubkeys (url, owner, pubkey, dt) values (?, ?, ?, ?)", key.apid+"#key", key.apid, key.Pubkey, dt)
				if err == nil {
					_, err = tx.Exec("insert into seckeys (owner, seckey) values (?, ?)", key.apid, key.Seckey)
				}
				if err != nil {
					elog.Fatal(err)
				}
			}
		}
		rows, err := tx.Query("select 0, gapid, gmeta from groups")
		if err != nil {
			elog.Fatal(err)
		}
		copykeys(rows)
		rows, err = tx.Query("select personid = 1, papid, personmeta from persons")
		if err != nil {
			elog.Fatal(err)
		}
		copykeys(rows)
		err = tx.Commit()
		if err != nil {
			elog.Fatal(err)
		}
		setversion(3)
		fallthrough
	case 3:
		try("create table notifs (notifid integer primary key, userid integer, dt text, flags integer, msg text, url text)")
		try("create index idxnotifs_userid on notifs(userid)")
		setversion(4)
		fallthrough
	case 4:
		try("insert into persons values (-1, '[deleted]', '[deleted]', '.', '{}')")
		setversion(5)
		fallthrough
	case 5:
		try("create table chats (chatid integer primary key, cgroupid integer, cpersonid integer, cxid text, capid text, cdt text, ccontent text)")
		try("create index idxchats_groupid on chats(cgroupid)")
		try("create index idxchats_xid on chats(cxid)")
		try("create index idxchats_apid on chats(capid)")
		setversion(6)
		fallthrough
	case 6:
		try("create table filters (filterid integer primary key, data text)")
		setversion(7)
		fallthrough
	case 7:
		try("create index idxtombstones_what on tombstones(what)")
		setversion(8)
		fallthrough
	case 8:
		try("alter table filters add column userid integer")
		try("update filters set userid = 0")
		setversion(9)
		fallthrough
	case 9:
		try("alter table subs add column postid integer")
		try("update subs set postid = 0")
		setversion(10)
		fallthrough
	case 10:
		try("create index idxsubs_groupid on subs(groupid) where groupid > 0")
		try("create index idxsubs_personid on subs(personid) where personid > 0")
		try("create index idxsubs_postid on subs(postid) where postid > 0")
		setversion(11)
		fallthrough
	case 11:
		try("analyze")

	default:
		elog.Fatalf("can't upgrade unknown version %d", dbversion)
	}
	os.Exit(0)
}

==> azorius-0.3.4.tgz: azorius-0.3.4/upgradedb.go <==
//
// Copyright (c) 2023 Ted Unangst <tedu@tedunangst.com>
//
// Permission to use, copy, modify, and distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

package main

import (
	"database/sql"
	"fmt"
	"os"
	"strings"
)

const myVersion = 13 // upgrade posts site

func upgradedb() {
	db := opendatabase()
	dbversion := 0
	getconfig("dbversion", &dbversion)
	getconfig("servername", &serverName)
	serverPrefix = fmt.Sprintf("https://%s/", serverName)

	var tx *sql.Tx
	try := func(s string, args ...interface{}) *sql.Rows {
		var err error
		var rows *sql.Rows
		if strings.HasPrefix(s, "select ") {
			if tx != nil {
				rows, err = tx.Query(s, args...)
			} else {
				rows, err = db.Query(s, args...)
			}
		} else {
			if tx != nil {
				_, err = tx.Exec(s, args...)
			} else {
				_, err = db.Exec(s, args...)
			}
		}
		if err != nil {
			elog.Fatalf("can't run %s: %s", s, err)
		}
		return rows
	}
	setversion := func(version int) {
		try("update config set value = ? where key = 'dbversion'", version)
	}

	switch dbversion {
	case 3:
		try("create table notifs (notifid integer primary key, userid integer, dt text, flags integer, msg text, url text)")
		try("create index idxnotifs_userid on notifs(userid)")
		setversion(4)
		fallthrough
	case 4:
		try("insert into persons values (-1, '[deleted]', '[deleted]', '.', '{}')")
		setversion(5)
		fallthrough
	case 5:
		try("create table chats (chatid integer primary key, cgroupid integer, cpersonid integer, cxid text, capid text, cdt text, ccontent text)")
		try("create index idxchats_groupid on chats(cgroupid)")
		try("create index idxchats_xid on chats(cxid)")
		try("create index idxchats_apid on chats(capid)")
		setversion(6)
		fallthrough
	case 6:
		try("create table filters (filterid integer primary key, data text)")
		setversion(7)
		fallthrough
	case 7:
		try("create index idxtombstones_what on tombstones(what)")
		setversion(8)
		fallthrough
	case 8:
		try("alter table filters add column userid integer")
		try("update filters set userid = 0")
		setversion(9)
		fallthrough
	case 9:
		try("alter table subs add column postid integer")
		try("update subs set postid = 0")
		setversion(10)
		fallthrough
	case 10:
		try("create index idxsubs_groupid on subs(groupid) where groupid > 0")
		try("create index idxsubs_personid on subs(personid) where personid > 0")
		try("create index idxsubs_postid on subs(postid) where postid > 0")
		setversion(11)
		fallthrough
	case 11:
		try("alter table posts add column site text")
		try("update posts set site = ''")
		try("create index idxposts_site on posts(site)")
		setversion(12)
		fallthrough
	case 12:
		tx, err := db.Begin()
		if err != nil {
			elog.Fatalf("can't begin tx")
		}
		rows := try("select postid, lnk from posts where lnk <> ''")
		posts := make(map[int64]string)
		for rows.Next() {
			var postid int64
			var lnk string
			err := rows.Scan(&postid, &lnk)
			if err != nil {
				elog.Fatalf("can't scan link: %s")
			}
			m := re_linkhost.FindStringSubmatch(lnk)
			if len(m) > 1 {
				posts[postid] = strings.ToLower(m[1])
			}
		}
		rows.Close()
		for id, site := range posts {
			try("update posts set site = ? where postid = ?", site, id)
		}
		err = tx.Commit()
		if err != nil {
			elog.Fatalf("can't commit tx")
		}
		setversion(13)
		fallthrough
	case 13:
		try("analyze")

	default:
		elog.Fatalf("can't upgrade unknown version %d", dbversion)
	}
	os.Exit(0)
}
